// undefined expression class -*- c++ -*-

#ifdef __GNUC__
# pragma implementation
#endif // __GNUC__
#include "Undefined.h"
#include "Printer.h"

/** @file Undefined.C
 * Undefined literal
 */

Undefined::Undefined (enum Fatalness fatalness) :
  Expression (),
  myFatalness (fatalness)
{
}

Undefined::~Undefined ()
{
}

class Value*
Undefined::do_eval (const class Valuation& valuation) const
{
  switch (myFatalness) {
  case fError:
    valuation.flag (errUndef, *this);
    return 0;
  case fFatalError:
    valuation.flag (errFatal, *this);
    return 0;
  }
  assert (false);
  return 0;
}

bool
Undefined::depends (const class VariableSet&,
		    bool) const
{
  return false;
}

bool
Undefined::forVariables (bool (*)
			 (const class Expression&,void*),
			 void*) const
{
  return true;
}

#ifdef EXPR_COMPILE
# include "CExpression.h"

void
Undefined::compile (class CExpression& cexpr,
		    unsigned indent,
		    const char*,
		    const class VariableSet*) const
{
  cexpr.compileError (indent, myFatalness == fError ? errUndef : errFatal);
}

#endif // EXPR_COMPILE

void
Undefined::display (const class Printer& printer) const
{
  printer.printRaw (myFatalness == fFatalError ? "fatal" : "undefined");
}
